@@ -57,7 +57,7 @@ saving and editing of associated data, cutting / copying, etc)
 */
 class CNItem : public Item, public CIWidgetMgr
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	CNItem( ICNDocument *_icnView, bool newItem, const TQString &id );
