@@ -31,7 +31,7 @@ typedef TQValueVector<Pin*> PinVector;
 */
 class ECNode : public Node
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		ECNode( ICNDocument *icnDocument, Node::node_type type, node_dir dir, const TQPoint &pos, TQString *id = 0L );
