@@ -605,7 +605,7 @@ void TextDocument::slotUpdateMarksInfo()
 		{
 			TDEAction * a = new TDEAction( i18n("%1 - %2").arg( TQString::number( mark->line+1 ) ).arg( m_doc->textLine(mark->line) ),
 									   0, this, TQT_SLOT(slotBookmarkRequested()), this,
-									   TQString("bookmark_%1").arg(TQString::number(mark->line).ascii()) );
+									   TQString("bookmark_%1").arg(TQString::number(mark->line)).latin1() );
 			m_bookmarkActions.append(a);
 		}
 	}
@@ -616,7 +616,7 @@ void TextDocument::slotUpdateMarksInfo()
 
 void TextDocument::slotBookmarkRequested()
 {
-	const TQObject * s = TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()));
+	const TQObject * s = sender();
 	if (!s) return;
 	
 	TQString name = s->name();
